putDeviceToken static method

  1. @Deprecated("Use [instance.putDeviceToken] instead")
void putDeviceToken(
  1. String deviceToken
)

Sets the device token for push notifications.

deviceToken is the push notification token obtained from the platform.

This method associates the device token with the current user for targeted push notifications.

Implementation

@Deprecated("Use [instance.putDeviceToken] instead")
static void putDeviceToken(String deviceToken) {
  instance.putDeviceToken(deviceToken);
}