putDeviceToken static method
Sets the device token for push notifications.
deviceToken is the push notification token obtained from the platform.
This method associates the device token with the current user for targeted push notifications.
Implementation
@Deprecated("Use [instance.putDeviceToken] instead")
static void putDeviceToken(String deviceToken) {
instance.putDeviceToken(deviceToken);
}